@@ -544,8 +544,12 @@ class DescribeCaptchaDataSumResponse(AbstractModel):
         :type CaptchaMsg: str
         :param CaptchaCode: 成功返回0  其它失败
         :type CaptchaCode: int
-        :param CheckTicketSum: 票据校验量
+        :param CheckTicketSum: 票据校验总量
         :type CheckTicketSum: int
+        :param TicketThroughputSum: 票据验证通过量
+        :type TicketThroughputSum: int
+        :param TicketInterceptSum: 票据验证拦截量
+        :type TicketInterceptSum: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -556,6 +560,8 @@ class DescribeCaptchaDataSumResponse(AbstractModel):
         self.CaptchaMsg = None
         self.CaptchaCode = None
         self.CheckTicketSum = None
+        self.TicketThroughputSum = None
+        self.TicketInterceptSum = None
         self.RequestId = None
 
 
@@ -567,6 +573,8 @@ class DescribeCaptchaDataSumResponse(AbstractModel):
         self.CaptchaMsg = params.get("CaptchaMsg")
         self.CaptchaCode = params.get("CaptchaCode")
         self.CheckTicketSum = params.get("CheckTicketSum")
+        self.TicketThroughputSum = params.get("TicketThroughputSum")
+        self.TicketInterceptSum = params.get("TicketInterceptSum")
         self.RequestId = params.get("RequestId")
 
 
@@ -1145,34 +1153,20 @@ class DescribeCaptchaResultResponse(AbstractModel):
     def __init__(self):
         r"""
         :param CaptchaCode: 1 OK 验证通过
-6 user code len error 验证码长度不匹配，请检查请求是否带Randstr参数，Randstr参数大小写是否有误
-7 captcha no match 验证码答案不匹配/Randstr参数不匹配，请重新生成Randstr、Ticket进行校验
-8 verify timeout 验证码签名超时，票据已过期，请重新生成Randstr、Ticket票进行校验
-9 Sequnce repeat 验证码签名重放，票据重复使用，请重新生成Randstr、Ticket进行校验
-10 Sequnce invalid 验证码签名序列
-11 Cookie invalid 验证码cookie信息不合法，非法请求，可能存在不规范接入
-12 sig len error 签名长度错误
-13 verify ip no match ip不匹配，非法请求，可能存在不规范接入
-15 decrypt fail 验证码签名解密失败，票据校验失败，请检查Ticket票据是否与前端返回Ticket一致
-16 appid no match 验证码强校验appid错误，前端代码 data-appid 和后端 CaptchaAppId 所填写的值，必须和 验证码控制台 中【验证详情】>【基础配置】内的 AppID 一致,请检查CaptchaAppId是否为控制台基础配置界面系统分配的APPID
-17 cmd no much 验证码系统命令不匹配
-18 uin no match 号码不匹配
-19 seq redirect 重定向验证
-20 opt no vcode 操作使用pt免验证码校验错误
-21 diff 差别，验证错误 
-该情况出现原因一般为，当验证码前端生成terror格式票据并进行后端票据校验时，用户网络较差，该情况下仍会返回可用票据，业务侧可以自行根据需要，进行票据生成或做其他处理。详情参见 [验证码Web前端接入-异常处理文档](https://cloud.tencent.com/document/product/1110/36841#.E5.BC.82.E5.B8.B8.E5.A4.84.E7.90.86)。
-22 captcha type not match 验证码类型与拉取时不一致
-23 verify type error 验证类型错误
-24 invalid pkg 非法请求包
-25 bad visitor 策略拦截
-26 system busy 系统内部错误
-100 param err appsecretkey 参数校验错误，CaptchaAppId 与对应 AppSecretKey 不一致，需检查 AppSecretKey 参数是否有误。其中 CaptchaAppId、 AppSecretKey 在 验证码控制台 的【验证详情】>【基础配置】中获取
-104 Ticket Reuse 票据重复使用，同个票据验证多次，请重新生成Randstr、Ticket进行校验
+7 captcha no match 传入的Randstr不合法，请检查Randstr是否与前端返回的Randstr一致
+8 ticket expired 传入的Ticket已过期（Ticket有效期5分钟），请重新生成Ticket、Randstr进行校验
+9 ticket reused 传入的Ticket被重复使用，请重新生成Ticket、Randstr进行校验
+15 decrypt fail 传入的Ticket不合法，请检查Ticket是否与前端返回的Ticket一致
+16 appid-ticket mismatch 传入的CaptchaAppId错误，请检查CaptchaAppId是否与前端传入的CaptchaAppId一致，并且保障CaptchaAppId是从验证码控制台【验证管理】->【基础配置】中获取
+21 diff 票据校验异常，可能的原因是（1）若Ticket包含terror前缀，一般是由于用户网络较差，导致前端自动容灾，而生成了容灾票据，业务侧可根据需要进行跳过或二次处理。（2）若Ticket不包含terror前缀，则是由于验证码风控系统发现请求有安全风险，业务侧可根据需要进行拦截。
+100 appid-secretkey-ticket mismatch 参数校验错误，（1）请检查CaptchaAppId与AppSecretKey是否正确，CaptchaAppId、AppSecretKey需要在验证码控制台【验证管理】>【基础配置】中获取（2）请检查传入的Ticket是否由传入的CaptchaAppId生成
         :type CaptchaCode: int
         :param CaptchaMsg: 状态描述及验证错误信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type CaptchaMsg: str
-        :param EvilLevel: [0,100]，恶意等级
+        :param EvilLevel: 无感验证模式下，该参数返回验证结果：
+EvilLevel=0 请求无恶意
+EvilLevel=100 请求有恶意
 注意：此字段可能返回 null，表示取不到有效值。
         :type EvilLevel: int
         :param GetCaptchaTime: 前端获取验证码时间，时间戳格式
